Module action_diff

Module action_diff 

Serialization-friendly representation of changes to ActionState.

These are predominantly intended for use in networked games, where the server needs to know what the players are doing. They would like a compact, semantically meaningful representation of the changes to the game state without needing to know about things like keybindings or input devices.

Structs

ActionDiffMessage
Will store an ActionDiff as well as the entity that generated it.
SummarizedActionState
Stores the state of all actions in the current frame, keyed by the entity that owns each ActionState.

Enums

ActionDiff
Stores presses and releases of buttons without timing information