pub struct ActionData {
    pub state: ButtonState,
    pub value: f32,
    pub axis_pair: Option<DualAxisData>,
    pub timing: Timing,
    pub consumed: bool,
}
Metadata about an Actionlike action

If a button is released, its reasons_pressed should be empty.

Fields

state: ButtonState

Is the action pressed or released?

value: f32

The “value” of the binding that triggered the action.

See [ActionState::action_value()] for more details.

Warning: this value may not be bounded as you might expect. Consider clamping this to account for multiple triggering inputs.

axis_pair: Option<DualAxisData>

The [AxisPair] of the binding that triggered the action.

See [ActionState::action_axis_pair()] for more details.

timing: Timing

When was the button pressed / released, and how long has it been held for?

consumed: bool

Was this action consumed by ActionState::consume?

Actions that are consumed cannot be pressed again until they are explicitly released. This ensures that consumed actions are not immediately re-pressed by continued inputs.