pub struct Timing {
    pub instant_started: Option<Instant>,
    pub current_duration: Duration,
    pub previous_duration: Duration,
}
Stores information about when an action was pressed or released

This struct is principally used as a field on ActionData, which itself lives inside an ActionState.

Fields

instant_started: Option<Instant>

The [Instant] at which the button was pressed or released Recorded as the Time at the start of the tick after the state last changed. If this is none, Timing::tick has not been called yet.

current_duration: Duration

The Duration for which the button has been pressed or released.

This begins at Duration::ZERO when ActionState::update is called.

previous_duration: Duration

The Duration for which the button was pressed or released before the state last changed.

Implementations

Advances the current_duration of this timer

If the instant_started is None, it will be set to the current time. This design allows us to ensure that the timing is always synchronized with the start of each frame.

Flips the metaphorical hourglass, storing current_duration in previous_duration and resetting instant_started

This method is called whenever actions are pressed or released