#[non_exhaustive]pub enum ClashStrategy {
PressAll,
PrioritizeLongest,
}Expand description
How should clashing inputs by handled by an InputMap?
Inputs “clash” if and only if the Buttonlike components of one user input is a strict subset of the other.
For example:
SandW: does not clashControlLeft + SandS: clashesSandS: does not clashControlLeft + SandAltLeft + S: does not clashControlLeft + S,AltLeft + SandControlLeft + AltLeft + S: clashes
This strategy is only used when assessing the actions and input holistically,
in InputMap::process_actions, using InputMap::handle_clashes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PressAll
All matching inputs will always be pressed
PrioritizeLongest
Only press the action that corresponds to the longest chord
This is the default strategy.
Implementations
Sourceimpl ClashStrategy
impl ClashStrategy
Sourcepub fn variants() -> &'static [ClashStrategy]
pub fn variants() -> &'static [ClashStrategy]
Returns the list of all possible clash strategies.