pub enum UpdatedValue {
Button(ButtonValue),
Axis(f32),
DualAxis(Vec2),
TripleAxis(Vec3),
}Expand description
An enum representing the updated value of an action.
Used in UpdatedActions to store the updated state of each action.
Variants
Button(ButtonValue)
A buttonlike action that was pressed or released.
Axis(f32)
An axislike action that was updated.
DualAxis(Vec2)
A dual-axislike action that was updated.
TripleAxis(Vec3)
A triple-axislike action that was updated.