pub struct InputStreams<'a> {
    pub gamepad_buttons: &'a Input<GamepadButton>,
    pub gamepad_button_axes: &'a Axis<GamepadButton>,
    pub gamepad_axes: &'a Axis<GamepadAxis>,
    pub gamepads: &'a Gamepads,
    pub keycodes: Option<&'a Input<KeyCode>>,
    pub mouse_buttons: Option<&'a Input<MouseButton>>,
    pub mouse_wheel: Option<&'a Events<MouseWheel>>,
    pub mouse_motion: &'a Events<MouseMotion>,
    pub associated_gamepad: Option<Gamepad>,
}
A collection of [Input] structs, which can be used to update an InputMap.

These are typically collected via a system from the World as resources.

Fields

gamepad_buttons: &'a Input<GamepadButton>

A [GamepadButton] [Input] stream

gamepad_button_axes: &'a Axis<GamepadButton>

A [GamepadButton] [Axis] stream

gamepad_axes: &'a Axis<GamepadAxis>

A [GamepadAxis] [Axis] stream

gamepads: &'a Gamepads

A list of registered gamepads

keycodes: Option<&'a Input<KeyCode>>

A [KeyCode] [Input] stream

mouse_buttons: Option<&'a Input<MouseButton>>

A [MouseButton] [Input] stream

mouse_wheel: Option<&'a Events<MouseWheel>>

A [MouseWheel] event stream

mouse_motion: &'a Events<MouseMotion>

A [MouseMotion] event stream

associated_gamepad: Option<Gamepad>

The [Gamepad] that this struct will detect inputs from

Implementations

Construct an InputStreams from a [World]

Guess which registered [Gamepad] should be used.

If an associated gamepad is set, use that. Otherwise use the first registered gamepad, if any.

Is the input matched by the InputStreams?

Is at least one of the inputs pressed?

Is the button pressed?

Are all of the buttons pressed?

Get the “value” of the input.

For binary inputs such as buttons, this will always be either 0.0 or 1.0. For analog inputs such as axes, this will be the axis value.

UserInput::Chord inputs are also considered binary and will return 0.0 or 1.0 based on whether the chord has been pressed.

Warning

If you need to ensure that this value is always in the range [-1., 1.], be sure to clamp the returned data.

Get the axis pair associated to the user input.

If input is not a DualAxis or VirtualDPad, returns None.

See ActionState::action_axis_pair() for usage.

Warning

If you need to ensure that this value is always in the range [-1., 1.], be sure to clamp the returned data.