#[non_exhaustive]
pub enum InputKind {
GamepadButton(GamepadButtonType),
SingleAxis(SingleAxis),
DualAxis(DualAxis),
Keyboard(KeyCode),
Modifier(Modifier),
Mouse(MouseButton),
MouseWheel(MouseWheelDirection),
MouseMotion(MouseMotionDirection),
}Expand description
The different kinds of supported input bindings.
See [InputMode] for the value-less equivalent. Commonly stored in the UserInput enum.
Unfortunately we cannot use a trait object here, as the types used by Input
require traits that are not object-safe.
Please contact the maintainers if you need support for another type!
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GamepadButton(GamepadButtonType)
A button on a gamepad
SingleAxis(SingleAxis)
A single axis of continous motion
DualAxis(DualAxis)
Two paired axes of continous motion
Keyboard(KeyCode)
A button on a keyboard
Modifier(Modifier)
A keyboard modifier, like Ctrl or Alt, which doesn’t care about which side it’s on.
Mouse(MouseButton)
A button on a mouse
MouseWheel(MouseWheelDirection)
A discretized mousewheel movement
MouseMotion(MouseMotionDirection)
A discretized mouse movement