Axislike

Trait Axislike 

pub trait Axislike:
    UserInput
    + DynClone
    + DynEq
    + DynHash
    + Reflect
    + Serialize {
    // Required method
    fn get_value(
        &self,
        input_store: &CentralInputStore,
        gamepad: Entity,
    ) -> Option<f32>;

    // Provided methods
    fn value(&self, input_store: &CentralInputStore, gamepad: Entity) -> f32 { ... }
    fn set_value(&self, world: &mut World, value: f32) { ... }
    fn set_value_as_gamepad(
        &self,
        world: &mut World,
        value: f32,
        _gamepad: Option<Entity>,
    ) { ... }
}
A trait used for axis-like user inputs, which provide a continuous value.

Required Methods

fn get_value( &self, input_store: &CentralInputStore, gamepad: Entity, ) -> Option<f32>

Gets the current value of the input as an f32.

Provided Methods

fn value(&self, input_store: &CentralInputStore, gamepad: Entity) -> f32

Gets the current value of the input as an f32.

fn set_value(&self, world: &mut World, value: f32)

Simulate an axis-like input by sending the appropriate message.

This method defaults to calling Axislike::set_value_as_gamepad if not overridden, as is the case for gamepad-reliant inputs.

fn set_value_as_gamepad( &self, world: &mut World, value: f32, _gamepad: Option<Entity>, )

Simulate an axis-like input, pretending to be the provided gamepad Entity.

This method defaults to calling Axislike::set_value if not overridden, as is the case for things like a mouse wheel.

Use find_gamepad inside of this method to search for a gamepad to press the button on if the provided gamepad is None.