Serialization-friendly representation of changes to ActionState.
These are predominantly intended for use in networked games, where the server needs to know what the players are doing. They would like a compact, semantically meaningful representation of the changes to the game state without needing to know about things like keybindings or input devices.
Structs
- Action
Diff Message - Will store an
ActionDiffas well as the entity that generated it. - Summarized
Action State - Stores the state of all actions in the current frame, keyed by the entity that owns each
ActionState.
Enums
- Action
Diff - Stores presses and releases of buttons without timing information