Struct leafwing_input_manager::action_state::ActionData
source · pub struct ActionData {
pub state: ButtonState,
pub value: f32,
pub axis_pair: Option<DualAxisData>,
pub timing: Timing,
pub consumed: bool,
}Expand description
Metadata about an Actionlike action
If a button is released, its reasons_pressed should be empty.
Fields
state: ButtonStateIs the action pressed or released?
value: f32The “value” of the binding that triggered the action.
See [ActionState::action_value()] for more details.
Warning: this value may not be bounded as you might expect. Consider clamping this to account for multiple triggering inputs.
axis_pair: Option<DualAxisData>The [AxisPair] of the binding that triggered the action.
See [ActionState::action_axis_pair()] for more details.
timing: TimingWhen was the button pressed / released, and how long has it been held for?
consumed: boolWas this action consumed by ActionState::consume?
Actions that are consumed cannot be pressed again until they are explicitly released. This ensures that consumed actions are not immediately re-pressed by continued inputs.