Module leafwing_input_manager::axislike
source · Expand description
Tools for working with directional axis-like user inputs (gamesticks, D-Pads and emulated equvalents)
Structs
An
AxisType could not be converted into a more specialized variantTwo directional axes combined as one input.
A wrapped
Vec2 that represents the combaination of two input axes.A single directional axis with a configurable trigger zone.
A virtual Axis that you can get a value between -1 and 1 from.
A virtual DPad that you can get an [
AxisPair] fromEnums
The direction of motion of the mouse.
The direction of motion of the mouse wheel.